@@ -22,15 +22,16 @@ it.read <- function(fileNameIntensityTier, encoding = "UTF-8") {
     if (!isString(encoding)) {
         stop("Invalid 'encoding' parameter.")
     }
+    enc <- encoding
 
     if (encoding == "auto") {
-        encoding <- detectEncoding(fileNameIntensityTier)
+        enc <- detectEncoding(fileNameIntensityTier)
     }
 
-    if (encoding == "UTF-8") {
+    if (enc == "UTF-8") {
         flines <- readr::read_lines(fileNameIntensityTier, locale = readr::locale(encoding = "UTF-8"))  # Does not support UTF-16 at this point :-(
     } else {
-        fid <- file(fileNameIntensityTier, open = "r", encoding = encoding)
+        fid <- file(fileNameIntensityTier, open = "r", encoding = enc)
         flines <- readLines(fid)
         close(fid)
     }
@@ -42,6 +43,12 @@ it.read <- function(fileNameIntensityTier, encoding = "UTF-8") {
         stop("Empty file.")
     }
 
+    if (encoding == "UTF-8" & flines[1] != 'File type = "ooTextFile"') {
+        warning('Not an UTF-8 IntensityTier format, trying encoding = "auto"...')
+        x <- it.read(fileNameIntensityTier, encoding = "auto")
+        return(x)
+    }
+
     it_ind <- it.read_lines(flines)
     class(it_ind[[1]])["type"] <- "IntensityTier"
     class(it_ind[[1]])["name"] <- basename(fileNameIntensityTier)
@@ -341,7 +348,7 @@ it.plot <- function(it, group = "", snd = NULL) {
 #' it.plot(it2)
 #' }
 it.interpolate <- function(it, t) {
-    if (class(t) != "numeric"  &  class(t) != "integer") {
+    if (!("numeric" %in% class(t)) &  !("integer" %in% class(t))) {
         stop("t must be numeric vector")
     }
 
@@ -482,7 +489,7 @@ it.legendre <- function(it, npoints = 1000, npolynomials = 4) {
 #' lines(itLeg$t, itLeg$i, col = "blue")
 #' }
 it.legendreSynth <- function(c, npoints = 1000) {
-    if (class(c) != "numeric"  &  class(c) != "integer") {
+    if (!("numeric" %in% class(c)) &  !("integer" %in% class(c))) {
         stop("c must be numeric vector")
     }
 
